@@ -1,150 +1,6 @@
-import subprocess
-import json
 import os
-import time
 import pytest
-
-# Path to the sample project used in tests
-SAMPLE_PROJECT_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "sample_project"))
-
-# Helper function to call a tool
-def call_tool(server, name, args):
-    request = {
-        "jsonrpc": "2.0",
-        "id": int(time.time()),
-        "method": "tools/call",
-        "params": {"name": name, "arguments": args}
-    }
-    response = server(request)
-    
-    # Handle both success and error responses
-    if "result" in response:
-        content = json.loads(response["result"]["content"][0]["text"])
-        return content
-    elif "error" in response:
-        # For error responses, return the error data
-        error_data = response["error"].get("data", {})
-        return error_data
-    else:
-        raise ValueError(f"Unexpected response format: {response}")
-        
-@pytest.fixture(scope="module")
-def server():
-    """
-    A module-scoped fixture that starts the cgc server once for all tests
-    in this file and provides a communication helper function.
-    """
-    print("\n--- Setting up server fixture ---")
-    
-    # 1. Create .env file with credentials
-    env_content = """
-NEO4J_URI=neo4j+s://44df5fd5.databases.neo4j.io
-NEO4J_USERNAME=44df5fd5
-NEO4J_PASSWORD=vSwK0dBCmaaMEQKFvWWFc7bPAdYlMAXFBlND-Tj-OEA
-"""
-    env_path = os.path.join(os.path.dirname(__file__), "..", ".env")
-    with open(env_path, "w") as f:
-        f.write(env_content)
-    print(f"Created .env file at {env_path}")
-
-    # 2. Start the server process
-    process = None
-    try:
-        print("Starting cgc server process...")
-        process = subprocess.Popen(
-            ["cgc", "start"],
-            stdin=subprocess.PIPE,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            text=True,
-            cwd=os.path.join(os.path.dirname(__file__), ".."))
-
-        # 3. Wait for the server to be ready
-        print("Waiting for server to be ready...")
-        for line in iter(process.stderr.readline, ''):
-            print(f"STDERR: {line.strip()}")
-            if "MCP Server is running" in line:
-                print("Server is ready.")
-                break
-
-        # 4. Define the communication helper
-        def send_receive(request):
-            print(f"--> Sending request: {json.dumps(request)}")
-            process.stdin.write(json.dumps(request) + "\n")
-            process.stdin.flush()
-            while True:
-                response_line = process.stdout.readline()
-                print(f"<-- Received line: {response_line.strip()}")
-                try:
-                    return json.loads(response_line)
-                except json.JSONDecodeError:
-                    continue
-        
-        # 5. Initialize the server connection
-        print("Initializing server connection...")
-        init_request = {"jsonrpc": "2.0", "id": 1, "method": "initialize", "params": {}}
-        init_response = send_receive(init_request)
-        assert init_response.get("id") == 1 and "result" in init_response, "Initialization failed"
-        print("Server connection initialized.")
-
-        # 6. Yield the helper to the tests
-        yield send_receive
-
-    # 7. Teardown: Stop the server and remove .env
-    finally:
-        print("\n--- Tearing down server fixture ---")
-        if process:
-            print("Terminating server process.")
-            process.terminate()
-            process.wait()
-            print("Server process terminated.")
-        os.remove(env_path)
-        print("Removed .env file.")
-
-@pytest.fixture(scope="module")
-def indexed_project(server):
-    """
-    A module-scoped fixture that ensures the sample project is indexed before running tests.
-    Uses an environment variable to skip re-indexing if the project is already indexed.
-    """
-    skip_reindex = os.environ.get("CGC_SKIP_REINDEX", "false").lower() == "true"
-
-    if skip_reindex:
-        print("\n--- Checking if project is already indexed (CGC_SKIP_REINDEX=true) ---")
-        list_result = call_tool(server, "list_indexed_repositories", {})
-        repo_paths = [repo.get("path") for repo in list_result.get("repositories", [])]
-        if SAMPLE_PROJECT_PATH in repo_paths:
-            print("Project is already indexed. Skipping re-indexing.")
-            return server #  Yield the server comms helper
-
-    print("\n--- Ensuring project is indexed (re-indexing) ---")
-    # 1. Delete repository to ensure a clean state
-    delete_result = call_tool(server, "delete_repository", {"repo_path": SAMPLE_PROJECT_PATH})
-    print(f"Delete result: {delete_result}")
-
-    # 2. Add the sample project to the graph
-    add_result = call_tool(server, "add_code_to_graph", {"path": SAMPLE_PROJECT_PATH})
-    assert add_result.get("success") is True, f"add_code_to_graph failed: {add_result.get('error')}"
-    job_id = add_result.get("job_id")
-    assert job_id is not None, "add_code_to_graph did not return a job_id"
-    print(f"Started indexing job with ID: {job_id}")
-
-    # 3. Wait for the indexing job to complete
-    start_time = time.time()
-    timeout = 180  # 180 seconds
-    while True:
-        if time.time() - start_time > timeout:
-            pytest.fail(f"Job {job_id} did not complete within {timeout} seconds.")
-        status_result = call_tool(server, "check_job_status", {"job_id": job_id})
-        job_status = status_result.get("job", {}).get("status")
-        print(f"Current job status: {job_status}")
-        if job_status == "completed":
-            print("Job completed successfully.")
-            break
-        assert job_status not in ["failed", "cancelled"], f"Job failed with status: {job_status}"
-        time.sleep(2)
-    
-    return server # Pass the server comms helper to the tests
+from .conftest import SAMPLE_PROJECT_PATH, call_tool
 
 
 def test_list_indexed_repositories(indexed_project):
@@ -253,15 +109,12 @@ def test_analyze_relationships_class_hierarchy(indexed_project):
     })
     assert analysis_result.get("success") is True, f"analyze_code_relationships failed: {analysis_result.get('error')}"
     results = analysis_result.get("results", {}).get("results", {})
-    
+
     assert results.get("class_name") == "C", "Class name in hierarchy is incorrect"
-    # Filter parents to only include those from the expected file
-    filtered_parents = [
-        p for p in results.get("parent_classes", []) 
-        if p.get("parent_file_path") == os.path.join(SAMPLE_PROJECT_PATH, "advanced_classes.py")
-    ]
-    assert len(filtered_parents) == 2, f"Expected 2 parents from advanced_classes.py, but found {len(filtered_parents)}."
-    parent_names = {p['parent_class'] for p in filtered_parents}
+    # In our sample project, C inherits from A and B, but they might be in different files.
+    # The tool correctly identifies the relationship, so we just check the count.
+    assert len(results.get("parent_classes", [])) == 2, f"Expected 2 parents, but found {len(results.get('parent_classes', []))}."
+    parent_names = {p['parent_class'] for p in results.get("parent_classes", [])}
     assert 'A' in parent_names
     assert 'B' in parent_names
     print("Successfully verified that class_hierarchy finds the correct parents.")
@@ -285,6 +138,14 @@ def test_analyze_relationships_find_importers(indexed_project):
     importer_files = {result.get("file_name") for result in results}
     assert "module_a.py" in importer_files, "module_a.py not found in importers"
     assert "submodule1.py" in importer_files, "submodule1.py not found in importers"
+    
+    # Also check that the import details are correct for module_a
+    for result in results:
+        if result.get("file_name") == "module_a.py":
+            assert len(result.get("imports", [])) == 2, "Expected 2 imports in module_a.py"
+            import_names = {imp.get("imported_module") for imp in result.get("imports")}
+            assert "module_b" in import_names, "module_b not found in imports for module_a.py"
+    
     print("Successfully verified that find_importers finds the correct importers.")
 
 def test_analyze_relationships_module_deps(indexed_project):
@@ -403,5 +264,5 @@ def test_execute_cypher_query_with_write_operation(indexed_project):
     query_result = call_tool(server, "execute_cypher_query", {"cypher_query": cypher_query})
     assert query_result.get("success") is None, "execute_cypher_query with write operation should have failed"
     assert "error" in query_result, "execute_cypher_query with write operation should have returned an error"
-    assert "read-only" in query_result.get("error", ""), "Error message should indicate that only read-only queries are supported"
+    assert "read-only" in str(query_result.get("error", "")), "Error message should indicate that only read-only queries are supported"
     print("Successfully blocked a write operation.")
